@@ -16,8 +16,6 @@ ChromeUtils.defineModuleGetter(this, "SiteDataManager",
 
 ChromeUtils.import("resource://gre/modules/PrivateBrowsingUtils.jsm");
 
-const PREF_UPLOAD_ENABLED = "datareporting.healthreport.uploadEnabled";
-
 XPCOMUtils.defineLazyGetter(this, "AlertsServiceDND", function() {
   try {
     let alertsService = Cc["@mozilla.org/alerts-service;1"]
@@ -241,9 +239,6 @@ var gPrivacyPane = {
     if (AppConstants.MOZ_CRASHREPORTER) {
       this.initSubmitCrashes();
     }
-    this.initSubmitHealthReport();
-    setEventListener("submitHealthReportBox", "command",
-                     gPrivacyPane.updateSubmitHealthReport);
 
     let bundlePrefs = document.getElementById("bundlePreferences");
     let signonBundle = document.getElementById("signonBundle");
@@ -1359,35 +1354,6 @@ var gPrivacyPane = {
     }
   },
 
-  /**
-   * Initialize the health report service reference and checkbox.
-   */
-  initSubmitHealthReport() {
-    this._setupLearnMoreLink("datareporting.healthreport.infoURL", "FHRLearnMore");
-
-    let checkbox = document.getElementById("submitHealthReportBox");
-
-    // Telemetry is only sending data if MOZ_TELEMETRY_REPORTING is defined.
-    // We still want to display the preferences panel if that's not the case, but
-    // we want it to be disabled and unchecked.
-    if (Services.prefs.prefIsLocked(PREF_UPLOAD_ENABLED) ||
-        !AppConstants.MOZ_TELEMETRY_REPORTING) {
-      checkbox.setAttribute("disabled", "true");
-      return;
-    }
-
-    checkbox.checked = Services.prefs.getBoolPref(PREF_UPLOAD_ENABLED) &&
-                       AppConstants.MOZ_TELEMETRY_REPORTING;
-  },
-
-  /**
-   * Update the health report preference with state from checkbox.
-   */
-  updateSubmitHealthReport() {
-    let checkbox = document.getElementById("submitHealthReportBox");
-    Services.prefs.setBoolPref(PREF_UPLOAD_ENABLED, checkbox.checked);
-  },
-
   // Methods for Offline Apps (AppCache)
 
   /**
