@@ -18,6 +18,7 @@ Services.prefs.setBoolPref("devtools.webconsole.new-frontend-enabled", true);
 registerCleanupFunction(() => {
   Services.prefs.clearUserPref("devtools.webconsole.new-frontend-enabled");
 });
+const { PREFS } = require("devtools/client/webconsole/new-console-output/constants");
 
 const { prepareMessage } = require("devtools/client/webconsole/new-console-output/utils/messages");
 const { stubPackets } = require("devtools/client/webconsole/new-console-output/test/fixtures/stubs/index.js");
@@ -288,6 +289,9 @@ module.exports = {
 function* generateConsoleApiStubs() {
   const TEST_URI = "http://example.com/browser/devtools/client/webconsole/new-console-output/test/fixtures/stub-generators/test-console-api.html";
 
+  // Hiding log messages so we don't get unwanted client/server communication.
+  Services.prefs.setBoolPref(PREFS.FILTER.LOG, false);
+
   let stubs = {
     preparedMessages: [],
     packets: [],
@@ -308,20 +312,6 @@ function* generateConsoleApiStubs() {
         stubs.preparedMessages.push(formatStub(callKey, res));
         if (++i === keys.length) {
           toolbox.target.client.removeListener("consoleAPICall", listener);
-
-          // If this is a console.dir call, we need to wait for the properties
-          // to be fetched so we don't have any server errors.
-          if (callKey === "console.dir({C, M, Y, K})") {
-            const dirMsg = await waitForMessage(hud, `cyan: "C"`);
-            const oi = dirMsg.querySelector(".tree");
-            // If there's only one node, it means that the object inspector
-            // is not expanded.
-            if (oi.querySelectorAll(".node").length === 1) {
-              await waitForNodeMutation(oi, {
-                childList: true
-              });
-            }
-          }
           resolve();
         }
       };
@@ -344,6 +334,8 @@ function* generateConsoleApiStubs() {
     yield received;
   }
 
+  Services.prefs.clearUserPref(PREFS.FILTER.LOG);
+
   yield closeTabAndToolbox();
   return formatFile(stubs, "ConsoleMessage");
 }
@@ -527,44 +519,3 @@ function* generatePageErrorStubs() {
   yield closeTabAndToolbox();
   return formatFile(stubs, "ConsoleMessage");
 }
-
-/**
- * Wait for messages in the web console output, resolving once they are receieved.
- *
- * @param hud: the webconsole
- * @param message: string. text match in .message-body
- */
-function waitForMessage(hud, messageText) {
-  return new Promise(resolve => {
-    hud.ui.on("new-messages",
-      function messagesReceived(e, newMessages) {
-        for (let newMessage of newMessages) {
-          let messageBody = newMessage.node.querySelector(".message-body");
-          if (messageBody.textContent.includes(messageText)) {
-            info("Matched a message with text: " + messageText);
-            hud.ui.off("new-messages", messagesReceived);
-            resolve(newMessage.node);
-            break;
-          }
-        }
-      });
-  });
-}
-
-/**
-* Returns a promise that resolves when the node passed as an argument mutate
-* according to the passed configuration.
-*
-* @param {Node} node - The node to observe mutations on.
-* @param {Object} observeConfig - A configuration object for MutationObserver.observe.
-* @returns {Promise}
-*/
-function waitForNodeMutation(node, observeConfig = {}) {
-  return new Promise(resolve => {
-    const observer = new MutationObserver(mutations => {
-      resolve(mutations);
-      observer.disconnect();
-    });
-    observer.observe(node, observeConfig);
-  });
-}
