@@ -27,10 +27,10 @@ function run_test() {
 
 function test_simple_new_source() {
   gThreadClient.addOneTimeListener("newSource", function (event, packet) {
-    do_check_eq(event, "newSource");
-    do_check_eq(packet.type, "newSource");
-    do_check_true(!!packet.source);
-    do_check_true(!!packet.source.url.match(/test_new_source-01.js$/));
+    Assert.equal(event, "newSource");
+    Assert.equal(packet.type, "newSource");
+    Assert.ok(!!packet.source);
+    Assert.ok(!!packet.source.url.match(/test_new_source-01.js$/));
 
     finishClient(gClient);
   });
