@@ -10,7 +10,7 @@
 var protocol = require("devtools/shared/protocol");
 var {preEvent, types, Arg, RetVal} = protocol;
 
-var events = require("sdk/event/core");
+var EventEmitter = require("devtools/shared/event-emitter");
 
 function simpleHello() {
   return {
@@ -151,11 +151,11 @@ var ChildActor = protocol.ActorClassWithSpec(childSpec, {
   },
 
   emitEvents: function () {
-    events.emit(this, "event1", 1, 2, 3);
-    events.emit(this, "event2", 4, 5, 6);
-    events.emit(this, "named-event", 1, 2, 3);
-    events.emit(this, "object-event", this);
-    events.emit(this, "array-object-event", [this]);
+    EventEmitter.emit(this, "event1", 1, 2, 3);
+    EventEmitter.emit(this, "event2", 4, 5, 6);
+    EventEmitter.emit(this, "named-event", 1, 2, 3);
+    EventEmitter.emit(this, "object-event", this);
+    EventEmitter.emit(this, "array-object-event", [this]);
   },
 
   release: function () { },
@@ -314,7 +314,7 @@ var RootFront = protocol.FrontClassWithSpec(rootSpec, {
 
   getTemporaryChild: protocol.custom(function (id) {
     if (!this._temporaryHolder) {
-      this._temporaryHolder = protocol.Front(this.conn);
+      this._temporaryHolder = new protocol.Front(this.conn);
       this._temporaryHolder.actorID = this.actorID + "_temp";
       this._temporaryHolder = this.manage(this._temporaryHolder);
     }
@@ -451,8 +451,8 @@ function run_test() {
             trace.expectReceive({"from": "<actorid>"});
 
             expectRootChildren(2);
-            Assert.ok(!!!rootActor._temporaryHolder);
-            Assert.ok(!!!rootFront._temporaryHolder);
+            Assert.ok(!rootActor._temporaryHolder);
+            Assert.ok(!rootFront._temporaryHolder);
             for (let checkActor of checkActors) {
               Assert.ok(checkActor.destroyed);
               Assert.ok(checkActor.destroyed);
