@@ -107,7 +107,7 @@ public:
     : Runnable("VideoFrameContainerInvalidateRunnable")
     , mVideoFrameContainer(aVideoFrameContainer)
   {}
-  NS_IMETHOD Run()
+  NS_IMETHOD Run() override
   {
     MOZ_ASSERT(NS_IsMainThread());
 
