@@ -680,7 +680,12 @@ private:
     ScriptLoadInfo& loadInfo = mLoadInfos[aIndex];
 
     nsCOMPtr<nsIChannel> channel = do_QueryInterface(aRequest);
-    MOZ_ASSERT(channel == loadInfo.mChannel);
+
+    // Note that importScripts() can redirect.  In theory the main
+    // script could also encounter an internal redirect, but currently
+    // the assert does not allow that.
+    MOZ_ASSERT_IF(mIsMainScript, channel == loadInfo.mChannel);
+    loadInfo.mChannel = channel;
 
     // We synthesize the result code, but its never exposed to content.
     RefPtr<mozilla::dom::InternalResponse> ir =
@@ -1713,8 +1718,6 @@ CacheScriptLoader::ResolvedCallback(JSContext* aCx,
   MOZ_ASSERT(!mPump);
   rv = NS_NewInputStreamPump(getter_AddRefs(mPump),
                              inputStream,
-                             -1, /* default streamPos */
-                             -1, /* default streamLen */
                              0, /* default segsize */
                              0, /* default segcount */
                              false, /* default closeWhenDone */
