@@ -1,4 +1,3 @@
-
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* vim: set ts=8 sts=2 et sw=2 tw=80: */
 /* This Source Code Form is subject to the terms of the Mozilla Public
@@ -54,7 +53,8 @@ StaticRefPtr<ServiceWorkerRegistrar> gServiceWorkerRegistrar;
 } // namespace
 
 NS_IMPL_ISUPPORTS(ServiceWorkerRegistrar,
-                  nsIObserver)
+                  nsIObserver,
+                  nsIAsyncShutdownBlocker)
 
 void
 ServiceWorkerRegistrar::Initialize()
@@ -73,10 +73,6 @@ ServiceWorkerRegistrar::Initialize()
     DebugOnly<nsresult> rv = obs->AddObserver(gServiceWorkerRegistrar,
                                               "profile-after-change", false);
     MOZ_ASSERT(NS_SUCCEEDED(rv));
-
-    rv = obs->AddObserver(gServiceWorkerRegistrar, "profile-before-change",
-                          false);
-    MOZ_ASSERT(NS_SUCCEEDED(rv));
   }
 }
 
@@ -94,7 +90,6 @@ ServiceWorkerRegistrar::ServiceWorkerRegistrar()
   : mMonitor("ServiceWorkerRegistrar.mMonitor")
   , mDataLoaded(false)
   , mShuttingDown(false)
-  , mShutdownCompleteFlag(nullptr)
   , mRunnableCounter(0)
 {
   MOZ_ASSERT(NS_IsMainThread());
@@ -829,8 +824,8 @@ ServiceWorkerRegistrar::ShutdownCompleted()
 {
   MOZ_ASSERT(NS_IsMainThread());
 
-  MOZ_ASSERT(mShutdownCompleteFlag && !*mShutdownCompleteFlag);
-  *mShutdownCompleteFlag = true;
+  DebugOnly<nsresult> rv = GetShutdownPhase()->RemoveBlocker(this);
+  MOZ_ASSERT(NS_SUCCEEDED(rv));
 }
 
 void
@@ -1027,6 +1022,13 @@ ServiceWorkerRegistrar::ProfileStarted()
     return;
   }
 
+  rv = GetShutdownPhase()->AddBlocker(
+    this, NS_LITERAL_STRING(__FILE__), __LINE__,
+    NS_LITERAL_STRING("ServiceWorkerRegistrar: Flushing data"));
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return;
+  }
+
   nsCOMPtr<nsIEventTarget> target =
     do_GetService(NS_STREAMTRANSPORTSERVICE_CONTRACTID);
   MOZ_ASSERT(target, "Must have stream transport service");
@@ -1056,11 +1058,6 @@ ServiceWorkerRegistrar::ProfileStopped()
     }
   }
 
-  // We must set the pointer before potentially entering the fast-path shutdown
-  // below.
-  bool completed = false;
-  mShutdownCompleteFlag = &completed;
-
   PBackgroundChild* child = BackgroundChild::GetForCurrentThread();
   if (!child) {
     // Mutations to the ServiceWorkerRegistrar happen on the PBackground thread,
@@ -1095,8 +1092,40 @@ ServiceWorkerRegistrar::ProfileStopped()
   }
 
   child->SendShutdownServiceWorkerRegistrar();
+}
 
-  MOZ_ALWAYS_TRUE(SpinEventLoopUntil([&]() { return completed; }));
+// Async shutdown blocker methods
+
+NS_IMETHODIMP
+ServiceWorkerRegistrar::BlockShutdown(nsIAsyncShutdownClient* aClient)
+{
+  ProfileStopped();
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+ServiceWorkerRegistrar::GetName(nsAString& aName)
+{
+  aName = NS_LITERAL_STRING("ServiceWorkerRegistrar: Flushing data");
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+ServiceWorkerRegistrar::GetState(nsIPropertyBag**)
+{
+  return NS_OK;
+}
+
+nsCOMPtr<nsIAsyncShutdownClient>
+ServiceWorkerRegistrar::GetShutdownPhase() const
+{
+  nsCOMPtr<nsIAsyncShutdownService> svc = services::GetAsyncShutdown();
+  MOZ_RELEASE_ASSERT(svc);
+
+  nsCOMPtr<nsIAsyncShutdownClient> client;
+  Unused << svc->GetProfileBeforeChange(getter_AddRefs(client));
+  MOZ_RELEASE_ASSERT(client);
+  return Move(client);
 }
 
 void
@@ -1127,23 +1156,6 @@ ServiceWorkerRegistrar::Observe(nsISupports* aSubject, const char* aTopic,
     return NS_OK;
   }
 
-  if (!strcmp(aTopic, "profile-before-change")) {
-    // Hygiene; gServiceWorkerRegistrar should still be keeping a reference
-    // alive well past this phase of shutdown, but it's bad form to drop your
-    // last potentially owning reference and then make a call that requires you
-    // to still be alive, especially when you spin a nested event loop.
-    RefPtr<ServiceWorkerRegistrar> kungFuDeathGrip(this);
-
-    nsCOMPtr<nsIObserverService> observerService =
-      services::GetObserverService();
-    observerService->RemoveObserver(this, "profile-before-change");
-
-    // Shutting down, let's sync the data.
-    ProfileStopped();
-
-    return NS_OK;
-  }
-
   MOZ_ASSERT(false, "ServiceWorkerRegistrar got unexpected topic!");
   return NS_ERROR_UNEXPECTED;
 }
