@@ -171,11 +171,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(DrawSurfaceCommand)(mSurface, mDest, mSource, mSurfOptions, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->DrawSurface(mSurface, mDest, mSource, mSurfOptions, mOptions);
   }
@@ -209,11 +210,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(DrawSurfaceWithShadowCommand)(mSurface, mDest, mColor, mOffset, mSigma, mOperator);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->DrawSurfaceWithShadow(mSurface, mDest, mColor, mOffset, mSigma, mOperator);
   }
@@ -267,11 +269,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(ClearRectCommand)(mRect);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->ClearRect(mRect);
   }
@@ -295,11 +298,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(CopySurfaceCommand)(mSurface, mSourceRect, mDestination);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aTransform) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aTransform) const override
   {
     MOZ_ASSERT(!aTransform || !aTransform->HasNonIntegerTranslation());
     Point dest(Float(mDestination.x), Float(mDestination.y));
@@ -330,16 +334,17 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(FillRectCommand)(mRect, mPattern, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->FillRect(mRect, mPattern, mOptions);
   }
 
-  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const
+  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const override
   {
     aDeviceRect = aTransform.TransformBounds(mRect);
     return true;
@@ -367,11 +372,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(StrokeRectCommand)(mRect, mPattern, mStrokeOptions, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->StrokeRect(mRect, mPattern, mStrokeOptions, mOptions);
   }
@@ -400,11 +406,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(StrokeLineCommand)(mStart, mEnd, mPattern, mStrokeOptions, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->StrokeLine(mStart, mEnd, mPattern, mStrokeOptions, mOptions);
   }
@@ -431,16 +438,17 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(FillCommand)(mPath, mPattern, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->Fill(mPath, mPattern, mOptions);
   }
 
-  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const
+  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const override
   {
     aDeviceRect = mPath->GetBounds(aTransform);
     return true;
@@ -509,16 +517,17 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(StrokeCommand)(mPath, mPattern, mStrokeOptions, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->Stroke(mPath, mPattern, mStrokeOptions, mOptions);
   }
 
-  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const
+  bool GetAffectedRect(Rect& aDeviceRect, const Matrix& aTransform) const override
   {
     aDeviceRect = PathExtentsToMaxStrokeExtents(mStrokeOptions, mPath->GetBounds(aTransform), aTransform);
     return true;
@@ -549,7 +558,8 @@ public:
     memcpy(&mGlyphs.front(), aBuffer.mGlyphs, sizeof(Glyph) * aBuffer.mNumGlyphs);
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     GlyphBuffer glyphs = {
       mGlyphs.data(),
       (uint32_t)mGlyphs.size(),
@@ -557,7 +567,7 @@ public:
     CLONE_INTO(FillGlyphsCommand)(mFont, glyphs, mPattern, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     GlyphBuffer buf;
     buf.mNumGlyphs = mGlyphs.size();
@@ -592,7 +602,8 @@ public:
     memcpy(&mGlyphs.front(), aBuffer.mGlyphs, sizeof(Glyph) * aBuffer.mNumGlyphs);
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     GlyphBuffer glyphs = {
       mGlyphs.data(),
       (uint32_t)mGlyphs.size(),
@@ -600,7 +611,7 @@ public:
     CLONE_INTO(StrokeGlyphsCommand)(mFont, glyphs, mPattern, mStrokeOptions, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     GlyphBuffer buf;
     buf.mNumGlyphs = mGlyphs.size();
@@ -630,11 +641,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(MaskCommand)(mSource, mMask, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->Mask(mSource, mMask, mOptions);
   }
@@ -662,11 +674,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(MaskSurfaceCommand)(mSource, mMask, mOffset, mOptions);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->MaskSurface(mSource, mMask, mOffset, mOptions);
   }
@@ -689,11 +702,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(PushClipCommand)(mPath);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->PushClip(mPath);
   }
@@ -713,11 +727,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(PushClipRectCommand)(mRect);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->PushClipRect(mRect);
   }
@@ -747,11 +762,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(PushLayerCommand)(mOpaque, mOpacity, mMask, mMaskTransform, mBounds, mCopyBackground);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->PushLayer(mOpaque, mOpacity, mMask,
                    mMaskTransform, mBounds, mCopyBackground);
@@ -776,11 +792,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(PopClipCommand)();
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->PopClip();
   }
@@ -796,11 +813,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(PopLayerCommand)();
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->PopLayer();
   }
@@ -818,11 +836,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(SetTransformCommand)(mTransform);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aMatrix) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aMatrix) const override
   {
     if (aMatrix) {
       aDT->SetTransform(mTransform * (*aMatrix));
@@ -847,11 +866,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(SetPermitSubpixelAACommand)(mPermitSubpixelAA);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aMatrix) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix* aMatrix) const override
   {
     aDT->SetPermitSubpixelAA(mPermitSubpixelAA);
   }
@@ -870,11 +890,12 @@ public:
   {
   }
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(FlushCommand)();
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
   {
     aDT->Flush();
   }
@@ -890,11 +911,13 @@ public:
    , mBlur(aBlur)
   {}
 
-  void CloneInto(CaptureCommandList* aList) {
+  void CloneInto(CaptureCommandList* aList) override
+  {
     CLONE_INTO(BlurCommand)(mBlur);
   }
 
-  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const {
+  virtual void ExecuteOnDT(DrawTarget* aDT, const Matrix*) const override
+  {
     aDT->Blur(mBlur);
   }
 
