@@ -44,10 +44,10 @@ FocusState::Update(uint64_t aRootLayerTreeId,
                    uint64_t aOriginatingLayersId,
                    const FocusTarget& aState)
 {
-  FS_LOG("Update with rlt=%" PRIu64 ", olt=%" PRIu64 ", ft=(%d, %" PRIu64 ")\n",
+  FS_LOG("Update with rlt=%" PRIu64 ", olt=%" PRIu64 ", ft=(%s, %" PRIu64 ")\n",
          aRootLayerTreeId,
          aOriginatingLayersId,
-         static_cast<int>(aState.mType),
+         aState.Type(),
          aState.mSequenceNumber);
 
   // Update the focus tree with the latest target
@@ -75,53 +75,67 @@ FocusState::Update(uint64_t aRootLayerTreeId,
     // Accumulate event listener flags on the path to the focus target
     mFocusHasKeyEventListeners |= target.mFocusHasKeyEventListeners;
 
-    switch (target.mType) {
-      case FocusTarget::eRefLayer: {
-        // Guard against infinite loops
-        MOZ_ASSERT(mFocusLayersId != target.mData.mRefLayerId);
-        if (mFocusLayersId == target.mData.mRefLayerId) {
-          FS_LOG("Setting target to nil (bailing out of infinite loop, lt=%" PRIu64 ")\n",
-                 mFocusLayersId);
-          return;
-        }
+    // Match on the data stored in mData
+    // The match functions return true or false depending on whether the
+    // enclosing method, FocusState::Update, should return or continue to the
+    // next iteration of the while loop, respectively.
+    struct FocusTargetDataMatcher {
 
-        FS_LOG("Looking for target in lt=%" PRIu64 "\n", target.mData.mRefLayerId);
+      FocusState& mFocusState;
+      const uint64_t mSequenceNumber;
 
-        // The focus target is in a child layer tree
-        mFocusLayersId = target.mData.mRefLayerId;
-        break;
-      }
-      case FocusTarget::eScrollLayer: {
-        FS_LOG("Setting target to h=%" PRIu64 ", v=%" PRIu64 ", and seq=%" PRIu64 "\n",
-               target.mData.mScrollTargets.mHorizontal,
-               target.mData.mScrollTargets.mVertical,
-               target.mSequenceNumber);
-
-        // This is the global focus target
-        mFocusHorizontalTarget = target.mData.mScrollTargets.mHorizontal;
-        mFocusVerticalTarget = target.mData.mScrollTargets.mVertical;
-
-        // Mark what sequence number this target has so we can determine whether
-        // it is stale or not
-        mLastContentProcessedEvent = target.mSequenceNumber;
-
-        // If this focus state was just created and content has experienced more
-        // events then us, then assume we were recreated and sync focus sequence
-        // numbers.
-        if (mLastAPZProcessedEvent == 1 &&
-            mLastContentProcessedEvent > mLastAPZProcessedEvent) {
-          mLastAPZProcessedEvent = mLastContentProcessedEvent;
-        }
-        return;
-      }
-      case FocusTarget::eNone: {
+      bool match(const FocusTarget::NoFocusTarget& aNoFocusTarget) {
         FS_LOG("Setting target to nil (reached a nil target)\n");
 
         // Mark what sequence number this target has for debugging purposes so
         // we can always accurately report on whether we are stale or not
-        mLastContentProcessedEvent = target.mSequenceNumber;
-        return;
+        mFocusState.mLastContentProcessedEvent = mSequenceNumber;
+        return true;
       }
+
+      bool match(const FocusTarget::RefLayerId aRefLayerId) {
+        // Guard against infinite loops
+        MOZ_ASSERT(mFocusState.mFocusLayersId != aRefLayerId);
+        if (mFocusState.mFocusLayersId == aRefLayerId) {
+          FS_LOG("Setting target to nil (bailing out of infinite loop, lt=%" PRIu64 ")\n",
+                 mFocusState.mFocusLayersId);
+          return true;
+        }
+
+        FS_LOG("Looking for target in lt=%" PRIu64 "\n", aRefLayerId);
+
+        // The focus target is in a child layer tree
+        mFocusState.mFocusLayersId = aRefLayerId;
+        return false;
+      }
+
+      bool match(const FocusTarget::ScrollTargets& aScrollTargets) {
+        FS_LOG("Setting target to h=%" PRIu64 ", v=%" PRIu64 ", and seq=%" PRIu64 "\n",
+               aScrollTargets.mHorizontal,
+               aScrollTargets.mVertical,
+               mSequenceNumber);
+
+        // This is the global focus target
+        mFocusState.mFocusHorizontalTarget = aScrollTargets.mHorizontal;
+        mFocusState.mFocusVerticalTarget = aScrollTargets.mVertical;
+
+        // Mark what sequence number this target has so we can determine whether
+        // it is stale or not
+        mFocusState.mLastContentProcessedEvent = mSequenceNumber;
+
+        // If this focus state was just created and content has experienced more
+        // events then us, then assume we were recreated and sync focus sequence
+        // numbers.
+        if (mFocusState.mLastAPZProcessedEvent == 1 &&
+            mFocusState.mLastContentProcessedEvent > mFocusState.mLastAPZProcessedEvent) {
+          mFocusState.mLastAPZProcessedEvent = mFocusState.mLastContentProcessedEvent;
+        }
+        return true;
+      }
+    }; // struct FocusTargetDataMatcher
+
+    if (target.mData.match(FocusTargetDataMatcher{*this, target.mSequenceNumber})) {
+      return;
     }
   }
 }
