@@ -438,11 +438,8 @@ struct ParamTraits<mozilla::layers::FocusTarget::ScrollTargets>
 };
 
 template <>
-struct ParamTraits<mozilla::layers::FocusTarget::FocusTargetType>
-  : public ContiguousEnumSerializerInclusive<
-             mozilla::layers::FocusTarget::FocusTargetType,
-             mozilla::layers::FocusTarget::eNone,
-             mozilla::layers::FocusTarget::sHighestFocusTargetType>
+struct ParamTraits<mozilla::layers::FocusTarget::NoFocusTarget>
+  : public EmptyStructSerializer<mozilla::layers::FocusTarget::NoFocusTarget>
 {};
 
 template <>
@@ -454,28 +451,16 @@ struct ParamTraits<mozilla::layers::FocusTarget>
   {
     WriteParam(aMsg, aParam.mSequenceNumber);
     WriteParam(aMsg, aParam.mFocusHasKeyEventListeners);
-    WriteParam(aMsg, aParam.mType);
-    if (aParam.mType == mozilla::layers::FocusTarget::eRefLayer) {
-      WriteParam(aMsg, aParam.mData.mRefLayerId);
-    } else if (aParam.mType == mozilla::layers::FocusTarget::eScrollLayer) {
-      WriteParam(aMsg, aParam.mData.mScrollTargets);
-    }
+    WriteParam(aMsg, aParam.mData);
   }
 
   static bool Read(const Message* aMsg, PickleIterator* aIter, paramType* aResult)
   {
     if (!ReadParam(aMsg, aIter, &aResult->mSequenceNumber) ||
         !ReadParam(aMsg, aIter, &aResult->mFocusHasKeyEventListeners) ||
-        !ReadParam(aMsg, aIter, &aResult->mType)) {
+        !ReadParam(aMsg, aIter, &aResult->mData)) {
       return false;
     }
-
-    if (aResult->mType == mozilla::layers::FocusTarget::eRefLayer) {
-      return ReadParam(aMsg, aIter, &aResult->mData.mRefLayerId);
-    } else if (aResult->mType == mozilla::layers::FocusTarget::eScrollLayer) {
-      return ReadParam(aMsg, aIter, &aResult->mData.mScrollTargets);
-    }
-
     return true;
   }
 };
